@@ -26,16 +26,18 @@ class Cards():
         with open(_cachepath, "w", encoding="utf-8") as f:
             json.dump(self.data, f, ensure_ascii=False)
 
-    def update(self) -> None:
+    def load(self) -> None:
         with open(_cachepath, "r", encoding="utf-8") as f:
             self.data = json.load(f)
 
-    def update_cards(self, event: Event, inv_dict: dict):
+    def update(self, event: Event, inv_dict: dict, qid: str = "", save: bool = True):
         group_id = get_group_id(event)
         if not self.data.get(group_id):
             self.data[group_id] = {}
-        self.data[group_id].update({str(event.sender.user_id): inv_dict})
-        self.save()
+        self.data[group_id].update(
+            {qid if qid else str(event.sender.user_id): inv_dict})
+        if save:
+            self.save()
 
     def get(self, event: Event, qid: str = "") -> dict:
         group_id = get_group_id(event)
@@ -45,15 +47,30 @@ class Cards():
         else:
             return None
 
-    def delete(self, event: Event):
-        if self.get(event):
-            self.data[get_group_id(event)] = {}
+    def delete(self, event: Event, qid: str = "", save: bool = True) -> bool:
+        if self.get(event, qid=qid):
+            if self.data[get_group_id(event)].get(qid if qid else str(event.sender.user_id)):
+                self.data[get_group_id(event)].pop(
+                    qid if qid else str(event.sender.user_id))
+            if save:
+                self.save()
+            return True
+        return False
+
+    def delete_skill(self, event: Event, skill_name: str, qid: str = "", save: bool = True) -> bool:
+        if self.get(event, qid=qid):
+            data = self.get(event, qid=qid)
+            if data["skills"].get(skill_name):
+                data["skills"].pop(skill_name)
+                self.update(event, data, qid=qid, save=save)
+                return True
+        return False
 
 
 cards = Cards()
 cache_cards = Cards()
 attrs_dict: dict = {
-    "名字": ["name", "名字"],
+    "名字": ["name", "名字", "名称"],
     "年龄": ["age", "年龄"],
     "力量": ["str", "力量"],
     "体质": ["con", "体质"],
@@ -72,18 +89,18 @@ def set_handler(event: Event, args: str):
     if not args:
         if cache_cards.get(event):
             card_data = cache_cards.get(event)
-            cards.update_cards(event, inv_dict=card_data)
+            cards.update(event, inv_dict=card_data)
             inv = Investigator().load(card_data)
             return "成功从缓存保存人物卡属性：\n" + inv.output()
         else:
-            return "未找到缓存数据，请先使用coc指令生成角色。"
+            return "未找到缓存数据，请先使用coc指令生成角色"
     else:
         args = args.split(" ")
         if cards.get(event):
             card_data = cards.get(event)
             inv = Investigator().load(card_data)
         else:
-            return "未找到已保存数据，请先使用空白set指令保存角色数据。"
+            return "未找到已保存数据，请先使用空白set指令保存角色数据"
         if len(args) >= 2:
             for attr, alias in attrs_dict.items():
                 if args[0] in alias:
@@ -93,9 +110,15 @@ def set_handler(event: Event, args: str):
                         try:
                             inv.__dict__[alias[0]] = int(args[1])
                         except ValueError:
-                            return "请输入正整数属性数据。"
-                    cards.update_cards(event, inv.__dict__)
+                            return "请输入正整数属性数据"
+                    cards.update(event, inv.__dict__)
                     return "设置调查员%s为：%s" % (attr, args[1])
+            try:
+                inv.skills[args[0]] = int(args[1])
+                cards.update(event, inv.__dict__)
+                return "设置调查员%s技能为：%s" % (args[0], args[1])
+            except ValueError:
+                return "请输入正整数技能数据"
 
 
 def show_handler(event: Event, args: str):
@@ -104,19 +127,46 @@ def show_handler(event: Event, args: str):
         if cards.get(event):
             card_data = cards.get(event)
             inv = Investigator().load(card_data)
-            r.append("已保存人物卡：\n" + inv.output())
+            r.append("使用中人物卡：\n" + inv.output())
         if cache_cards.get(event):
             card_data = cache_cards.get(event)
             inv = Investigator().load(card_data)
             r.append("已暂存人物卡：\n" + inv.output())
-    elif re.search(r"\[CQ:at,qq=\d+\]", args):
-        qid = re.search(r"\[CQ:at,qq=\d+\]", args).group()[10:-1]
+    elif args == "s":
+        if cards.get(event):
+            card_data = cards.get(event)
+            inv = Investigator().load(card_data)
+            r.append(inv.skills_output())
+    elif re.search(r"\[cq:at,qq=\d+\]", args):
+        qid = re.search(r"\[cq:at,qq=\d+\]", args).group()[10:-1]
         if cards.get(event, qid=qid):
             card_data = cards.get(event, qid=qid)
             inv = Investigator().load(card_data)
             r.append("查询到人物卡：\n" + inv.output())
+            if args[0] == "s":
+                r.append(inv.skills_output())
     if not r:
-        r.append("无保存/暂存信息。")
+        r.append("无保存/暂存信息")
+    return r
+
+
+def del_handler(event: Event, args: str):
+    r = []
+    args = args.split(" ")
+    for arg in args:
+        if not arg:
+            pass
+        elif arg == "c" and cache_cards.get(event):
+            if cache_cards.delete(event, save=False):
+                r.append("已清空暂存人物卡数据")
+        elif arg == "card" and cards.get(event):
+            if cards.delete(event):
+                r.append("已删除使用中的人物卡！")
+        else:
+            if cards.delete_skill(event, arg):
+                r.append("已删除技能"+arg)
+    if not r:
+        r.append(help_messages.del_)
     return r
 
 
